/*
 *******************************************************************************
 *
 *  Copyright 2024 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \author RIEGL LMS GmbH, Austria
 * \brief  Description of RIEGL RDB 2 database file contents
 *
 *  NOTE: All information in this file is preliminary, since the
 *        definition of the database schemas is not yet complete.
 *
 *******************************************************************************
 */

#ifndef RDB_2125FB67_4790_4EE4_BC63_844F2ACC9D90
#define RDB_2125FB67_4790_4EE4_BC63_844F2ACC9D90

// File schema version
const char* const RDB_SCHEMA_VERSION = "f274d50d";
const char* const RDB_SCHEMA_DATE = "2023-11-30";

// Schema for ".avg.fwa" files
const char* const RDB_SCHEMA_RIEGL_AVG_FWA(
    "{\"metadata\":[],\"identifier\":\"avg.fwa\",\"attributes\":[\"riegl.id*\",\"riegl"
    ".amplitude\",\"riegl.gain\",\"riegl.raw_range\",\"riegl.wfm_echo_time_offset"
    "\",\"riegl.wfm_sbl_id\",\"riegl.deviation?\",\"riegl.pulse_width?\"],\"extensi"
    "on\":\"avg.fwa\"}"
);

// Schema for ".avg.sbx" files
const char* const RDB_SCHEMA_RIEGL_AVG_SBX(
    "{\"metadata\":[],\"identifier\":\"avg.sbx\",\"attributes\":[\"riegl.id*\",\"riegl"
    ".wfm_sbl_channel\",\"riegl.wfm_sbl_mean\",\"riegl.wfm_sbl_std_dev\",\"riegl."
    "wfm_sbl_time_offset\",\"riegl.wfm_sda_first\",\"riegl.wfm_sda_count\"],\"ext"
    "ension\":\"avg.sbx\"}"
);

// Schema for ".avg.sidx" files
const char* const RDB_SCHEMA_RIEGL_AVG_SIDX(
    "{\"metadata\":[\"riegl.shot_info\",\"riegl.waveform_info\",\"riegl.echo_info?"
    "\",\"riegl.waveform_averaging_settings\"],\"identifier\":\"avg.sidx\",\"attrib"
    "utes\":[\"riegl.id\",\"riegl.shot_timestamp_hr*\",\"riegl.wfm_sbl_first\",\"ri"
    "egl.wfm_sbl_count\",\"riegl.echo_first?\",\"riegl.echo_count?\"],\"extension"
    "\":\"avg.sidx\"}"
);

// Schema for ".avg.sp{C}" files
const char* const RDB_SCHEMA_RIEGL_AVG_SPC(
    "{\"metadata\":[],\"identifier\":\"avg.sp{C}\",\"attributes\":[\"riegl.id*\",\"rie"
    "gl.wfm_sample_value\"],\"extension\":\"avg.sp{C}\"}"
);

// Schema for ".cpx" files
const char* const RDB_SCHEMA_RIEGL_CPX(
    "{\"metadata\":[\"riegl.geo_tag\",\"riegl.control_object_catalog\",\"riegl.ite"
    "m_names\",\"riegl.imported_files\"],\"identifier\":\"cpx\",\"attributes\":[\"rie"
    "gl.id\",\"riegl.xyz*\",\"riegl.xyz_accuracies\",\"riegl.control_object_type\""
    ",\"riegl.zenith_vector\",\"riegl.used_for_adjustment\",\"riegl.acquisition_"
    "date?\",\"riegl.cp_surface_inclination_angle\",\"riegl.cp_surface_inclinat"
    "ion_tolerance_angle\",\"riegl.cp_search_radius?\",\"riegl.cp_maximum_dista"
    "nce?\",\"riegl.import_line_number\"],\"extension\":\"cpx\"}"
);

// Schema for ".doix" files
const char* const RDB_SCHEMA_RIEGL_DOIX(
    "{\"metadata\":[],\"identifier\":\"doix\",\"attributes\":[\"riegl.id\",\"riegl.sho"
    "t_origin\",\"riegl.shot_direction*\",\"riegl.scan_line_index\",\"riegl.shot_"
    "index_line\"],\"extension\":\"doix\"}"
);

// Schema for ".eifx" files
const char* const RDB_SCHEMA_RIEGL_EIFX(
    "{\"metadata\":[\"riegl.device?\",\"riegl.time_base\",\"riegl.ttip_configurati"
    "on?\"],\"identifier\":\"eifx\",\"attributes\":[\"riegl.id\",\"riegl.event_timest"
    "amp*\",\"riegl.event_index?\",\"riegl.event_pulse_width?\",\"riegl.event_fak"
    "e_pulse?\",\"riegl.raw_line_angle?\",\"riegl.raw_frame_angle?\"],\"extension"
    "\":\"eifx\"}"
);

// Schema for ".epfx" files
const char* const RDB_SCHEMA_RIEGL_EPFX(
    "{\"metadata\":[\"riegl.device?\",\"riegl.geo_tag\",\"riegl.time_base\",\"riegl."
    "ttip_configuration?\"],\"identifier\":\"epfx\",\"attributes\":[\"riegl.id\",\"ri"
    "egl.event_timestamp*\",\"riegl.event_index?\",\"riegl.event_pulse_width?\","
    "\"riegl.event_fake_pulse?\",\"riegl.raw_line_angle?\",\"riegl.raw_frame_ang"
    "le?\",\"riegl.xyz\",\"riegl.model_cs_axis_x\",\"riegl.model_cs_axis_y\",\"rieg"
    "l.model_cs_axis_z\"],\"extension\":\"epfx\"}"
);

// Schema for ".fwa" files
const char* const RDB_SCHEMA_RIEGL_FWA(
    "{\"metadata\":[],\"identifier\":\"fwa\",\"attributes\":[\"riegl.id*\",\"riegl.amp"
    "litude\",\"riegl.gain\",\"riegl.raw_range\",\"riegl.wfm_echo_time_offset\",\"r"
    "iegl.wfm_sbl_id\",\"riegl.deviation?\",\"riegl.pulse_width?\",\"riegl.extinc"
    "tion?\",\"riegl.svb_amplitude_volumetric?\",\"riegl.svb_surface?\",\"riegl.s"
    "vb_bottom?\",\"riegl.svb_path_length?\"],\"extension\":\"fwa\"}"
);

// Schema for ".llhx" files
const char* const RDB_SCHEMA_RIEGL_LLHX(
    "{\"metadata\":[\"riegl.device?\",\"riegl.geo_tag\",\"riegl.time_base\"],\"ident"
    "ifier\":\"llhx\",\"attributes\":[\"riegl.pof_latitude\",\"riegl.pof_longitude\""
    ",\"riegl.pof_height\",\"riegl.pof_timestamp*\",\"riegl.pof_accuracy_north\","
    "\"riegl.pof_accuracy_east\",\"riegl.pof_accuracy_down\",\"riegl.pof_pdop\",\""
    "riegl.pof_hdop\",\"riegl.pof_vdop\",\"riegl.pof_age_of_corrections\",\"riegl"
    ".pof_baseline_length\",\"riegl.pof_solution_gnss\",\"riegl.pof_satellites_"
    "gnss\",\"riegl.id\"],\"extension\":\"llhx\"}"
);

// Schema for ".mpx" files
const char* const RDB_SCHEMA_RIEGL_MPX(
    "{\"metadata\":[\"riegl.geo_tag\",\"riegl.pixel_info\",\"riegl.time_base?\"],\"i"
    "dentifier\":\"mpx\",\"attributes\":[\"riegl.id\",\"riegl.xy_map*\",\"riegl.ampli"
    "tude\",\"riegl.reflectance\",\"riegl.deviation\",\"riegl.timestamp_min?\",\"ri"
    "egl.timestamp_max?\",\"riegl.point_count\",\"riegl.point_count_grid_cell\","
    "\"riegl.pixel_linear_sums?\",\"riegl.pixel_square_sums?\",\"riegl.height_mi"
    "n\",\"riegl.height_max\",\"riegl.height_mean\",\"riegl.height_center\",\"riegl"
    ".surface_normal\",\"riegl.pca_thickness\",\"riegl.std_dev\",\"riegl.voxel_co"
    "unt\"],\"extension\":\"mpx\"}"
);

// Schema for ".mtch" files
const char* const RDB_SCHEMA_RIEGL_MTCH(
    "{\"metadata\":[\"riegl.plane_patch_matching\"],\"identifier\":\"mtch\",\"attrib"
    "utes\":[\"riegl.xyz*\",\"riegl.plane_references\",\"riegl.plane_patch_distan"
    "ce\",\"riegl.plane_patch_lateral_distance\",\"riegl.plane_patch_link_vecto"
    "r\",\"riegl.id\"],\"extension\":\"mtch\"}"
);

// Schema for ".mvx" files
const char* const RDB_SCHEMA_RIEGL_MVX(
    "{\"metadata\":[\"riegl.geo_tag\",\"riegl.time_base?\",\"riegl.voxel_info\"],\"i"
    "dentifier\":\"mvx\",\"attributes\":[\"riegl.id\",\"riegl.xyz_map*\",\"riegl.ampl"
    "itude\",\"riegl.reflectance\",\"riegl.deviation\",\"riegl.timestamp_min?\",\"r"
    "iegl.timestamp_max?\",\"riegl.point_count\",\"riegl.shape_id\",\"riegl.covar"
    "iances?\",\"riegl.pca_axis_min\",\"riegl.pca_axis_max\",\"riegl.pca_extents\""
    ",\"riegl.std_dev\",\"riegl.voxel_collapsed\"],\"extension\":\"mvx\"}"
);

// Schema for ".obsx" files
const char* const RDB_SCHEMA_RIEGL_OBSX(
    "{\"metadata\":[\"riegl.geo_tag\",\"riegl.plane_slope_class_info?\",\"riegl.po"
    "intcloud_info\",\"riegl.sda1_source_files\"],\"identifier\":\"obsx\",\"attribu"
    "tes\":[\"riegl.xyz\",\"riegl.surface_normal\",\"riegl.plane_slope_class?\",\"r"
    "iegl.id*\",\"riegl.sda1_plane_patch_one\",\"riegl.sda1_plane_patch_two\",\"r"
    "iegl.sda1_source_file_one\",\"riegl.sda1_source_file_two\"],\"extension\":\""
    "obsx\"}"
);

// Schema for ".opefx" files
const char* const RDB_SCHEMA_RIEGL_OPEFX(
    "{\"metadata\":[\"riegl.device\",\"riegl.device_geometry\",\"riegl.geo_tag\",\"r"
    "iegl.georeferencing_parameters\",\"riegl.scan_pattern?\",\"riegl.time_base"
    "\",\"riegl.item_names\",\"riegl.control_object_reference_file\"],\"identifie"
    "r\":\"opefx\",\"attributes\":[\"riegl.id\",\"riegl.xyz*\",\"riegl.xyz_accuracies"
    "?\",\"riegl.surface_normal\",\"riegl.plane_up\",\"riegl.point_count\",\"riegl."
    "std_dev\",\"riegl.plane_width\",\"riegl.plane_height\",\"riegl.plane_confide"
    "nce_normal\",\"riegl.model_fit_quality?\",\"riegl.used_for_adjustment\",\"ri"
    "egl.xyz_socs\",\"riegl.timestamp\",\"riegl.mirror_facet\",\"riegl.platform_r"
    "py_ROCS_NED\",\"riegl.platform_drpy_ROCS_NED\",\"riegl.platform_xyz_ROCS_E"
    "NU\",\"riegl.platform_dxyz_ROCS_ENU\",\"riegl.sda.shift_vector\",\"riegl.raw"
    "_range\",\"riegl.raw_frame_angle\",\"riegl.raw_line_angle\",\"riegl.referenc"
    "e_object_id\"],\"extension\":\"opefx\"}"
);

// Schema for ".opp" files
const char* const RDB_SCHEMA_RIEGL_OPP(
    "{\"metadata\":[\"riegl.device\",\"riegl.device_geometry\",\"riegl.geo_tag\",\"r"
    "iegl.georeferencing_parameters\",\"riegl.scan_pattern?\",\"riegl.time_base"
    "\",\"riegl.item_names\",\"riegl.control_object_reference_file\"],\"identifie"
    "r\":\"opp\",\"attributes\":[\"riegl.id\",\"riegl.xyz*\",\"riegl.xyz_accuracies?\""
    ",\"riegl.surface_normal\",\"riegl.plane_up\",\"riegl.point_count\",\"riegl.st"
    "d_dev\",\"riegl.plane_width\",\"riegl.plane_height\",\"riegl.plane_confidenc"
    "e_normal\",\"riegl.model_fit_quality?\",\"riegl.used_for_adjustment\",\"rieg"
    "l.xyz_socs\",\"riegl.timestamp\",\"riegl.mirror_facet\",\"riegl.platform_rpy"
    "_ROCS_NED\",\"riegl.platform_drpy_ROCS_NED\",\"riegl.platform_xyz_ROCS_ENU"
    "\",\"riegl.platform_dxyz_ROCS_ENU\",\"riegl.sda.shift_vector\",\"riegl.raw_r"
    "ange\",\"riegl.raw_frame_angle\",\"riegl.raw_line_angle\",\"riegl.reference_"
    "object_id\"],\"extension\":\"opp\"}"
);

// Schema for ".opx" files
const char* const RDB_SCHEMA_RIEGL_OPX(
    "{\"metadata\":[\"riegl.device\",\"riegl.device_geometry\",\"riegl.geo_tag\",\"r"
    "iegl.georeferencing_parameters\",\"riegl.scan_pattern?\",\"riegl.time_base"
    "\",\"riegl.control_object_catalog\",\"riegl.item_names\",\"riegl.control_obj"
    "ect_reference_file\"],\"identifier\":\"opx\",\"attributes\":[\"riegl.id\",\"rieg"
    "l.xyz*\",\"riegl.control_object_type\",\"riegl.model_cs_axis_x?\",\"riegl.mo"
    "del_cs_axis_y?\",\"riegl.model_cs_axis_z?\",\"riegl.model_fit_quality?\",\"r"
    "iegl.obs_confidence_xy?\",\"riegl.obs_confidence_z?\",\"riegl.obs_signal_c"
    "onfidence_rot?\",\"riegl.obs_confidence_range?\",\"riegl.obs_confidence_th"
    "eta?\",\"riegl.obs_confidence_phi?\",\"riegl.point_count?\",\"riegl.used_for"
    "_adjustment\",\"riegl.xyz_socs\",\"riegl.timestamp\",\"riegl.mirror_facet\",\""
    "riegl.platform_rpy_ROCS_NED\",\"riegl.platform_drpy_ROCS_NED\",\"riegl.pla"
    "tform_xyz_ROCS_ENU\",\"riegl.platform_dxyz_ROCS_ENU\",\"riegl.sda.shift_ve"
    "ctor\",\"riegl.raw_range\",\"riegl.raw_frame_angle\",\"riegl.raw_line_angle\""
    ",\"riegl.reference_object_id\"],\"extension\":\"opx\"}"
);

// Schema for ".owp" files
const char* const RDB_SCHEMA_RIEGL_OWP(
    "{\"metadata\":[],\"identifier\":\"owp\",\"attributes\":[\"riegl.id*\",\"riegl.raw"
    "_range\",\"riegl.amplitude\",\"riegl.deviation\",\"riegl.gain\"],\"extension\":"
    "\"owp\"}"
);

// Schema for ".pefx" files
const char* const RDB_SCHEMA_RIEGL_PEFX(
    "{\"metadata\":[\"riegl.geo_tag\",\"riegl.vertex_info\",\"riegl.item_names\",\"r"
    "iegl.imported_files\"],\"identifier\":\"pefx\",\"attributes\":[\"riegl.id\",\"ri"
    "egl.xyz*\",\"riegl.xyz_accuracies?\",\"riegl.surface_normal\",\"riegl.plane_"
    "up\",\"riegl.std_dev\",\"riegl.plane_confidence_normal\",\"riegl.plane_width"
    "\",\"riegl.plane_height\",\"riegl.vertex_first\",\"riegl.vertex_count\",\"rieg"
    "l.used_for_adjustment\",\"riegl.acquisition_date?\",\"riegl.import_line_nu"
    "mber\",\"riegl.import_line_count\"],\"extension\":\"pefx\"}"
);

// Schema for ".pofx" files
const char* const RDB_SCHEMA_RIEGL_PROJECT_POFX(
    "{\"metadata\":[\"riegl.device?\",\"riegl.time_base\",\"riegl.trajectory_info\""
    "],\"identifier\":\"project.pofx\",\"attributes\":[\"riegl.id\",\"riegl.pof_time"
    "stamp*\",\"riegl.pof_latitude\",\"riegl.pof_longitude\",\"riegl.pof_height\","
    "\"riegl.pof_roll\",\"riegl.pof_pitch\",\"riegl.pof_yaw\",\"riegl.pof_path_len"
    "gth?\"],\"extension\":\"pofx\"}"
);

// Schema for ".pofx" files
const char* const RDB_SCHEMA_RIEGL_SCAN_POFX(
    "{\"metadata\":[\"riegl.device?\",\"riegl.time_base\",\"riegl.geo_tag\",\"riegl."
    "trajectory_info\"],\"identifier\":\"scan.pofx\",\"attributes\":[\"riegl.id\",\"r"
    "iegl.pof_timestamp*\",\"riegl.pof_latitude\",\"riegl.pof_longitude\",\"riegl"
    ".pof_height\",\"riegl.pof_roll\",\"riegl.pof_pitch\",\"riegl.pof_yaw\",\"riegl"
    ".pof_path_length?\",\"riegl.pof_xyz\",\"riegl.pof_roll_ned\",\"riegl.pof_pit"
    "ch_ned\",\"riegl.pof_yaw_ned\"],\"extension\":\"pofx\"}"
);

// Schema for ".poqx" files
const char* const RDB_SCHEMA_RIEGL_PROJECT_POQX(
    "{\"metadata\":[\"riegl.time_base\",\"riegl.trajectory_info\"],\"identifier\":\""
    "project.poqx\",\"attributes\":[\"riegl.id\",\"riegl.pof_timestamp*\",\"riegl.p"
    "of_accuracy_north\",\"riegl.pof_accuracy_east\",\"riegl.pof_accuracy_down\""
    ",\"riegl.pof_accuracy_roll\",\"riegl.pof_accuracy_pitch\",\"riegl.pof_accur"
    "acy_yaw\",\"riegl.pof_path_length?\",\"riegl.pof_pdop\",\"riegl.pof_satellit"
    "es_gnss?\",\"riegl.pof_satellites_gps?\",\"riegl.pof_satellites_glonass?\","
    "\"riegl.pof_satellites_beidou?\",\"riegl.pof_satellites_galileo?\",\"riegl."
    "pof_satellites_qzss?\"],\"extension\":\"poqx\"}"
);

// Schema for ".poqx" files
const char* const RDB_SCHEMA_RIEGL_SCAN_POQX(
    "{\"metadata\":[\"riegl.time_base\",\"riegl.trajectory_info\"],\"identifier\":\""
    "scan.poqx\",\"attributes\":[\"riegl.id\",\"riegl.pof_timestamp*\",\"riegl.pof_"
    "accuracy_north\",\"riegl.pof_accuracy_east\",\"riegl.pof_accuracy_down\",\"r"
    "iegl.pof_accuracy_roll\",\"riegl.pof_accuracy_pitch\",\"riegl.pof_accuracy"
    "_yaw\",\"riegl.pof_path_length?\",\"riegl.pof_pdop\",\"riegl.pof_satellites_"
    "gnss?\",\"riegl.pof_satellites_gps?\",\"riegl.pof_satellites_glonass?\",\"ri"
    "egl.pof_satellites_beidou?\",\"riegl.pof_satellites_galileo?\",\"riegl.pof"
    "_satellites_qzss?\"],\"extension\":\"poqx\"}"
);

// Schema for ".ppx" files
const char* const RDB_SCHEMA_RIEGL_PPX(
    "{\"metadata\":[\"riegl.device\",\"riegl.time_base\"],\"identifier\":\"ppx\",\"att"
    "ributes\":[\"riegl.id\",\"riegl.pps_timestamp_intern*\",\"riegl.pps_timestam"
    "p_extern\"],\"extension\":\"ppx\"}"
);

// Schema for ".ptch" files
const char* const RDB_SCHEMA_RIEGL_PROJECT_PTCH(
    "{\"metadata\":[\"riegl.device\",\"riegl.geo_tag?\",\"riegl.scan_pattern?\",\"ri"
    "egl.time_base?\",\"riegl.plane_patch_statistics?\"],\"identifier\":\"project"
    ".ptch\",\"attributes\":[\"riegl.xyz*\",\"riegl.surface_normal\",\"riegl.plane_"
    "up\",\"riegl.reflectance?\",\"riegl.point_count\",\"riegl.std_dev\",\"riegl.pl"
    "ane_width\",\"riegl.plane_height\",\"riegl.plane_count\",\"riegl.covariances"
    "\",\"riegl.id\"],\"extension\":\"ptch\"}"
);

// Schema for ".ptch" files
const char* const RDB_SCHEMA_RIEGL_SCAN_PTCH(
    "{\"metadata\":[\"riegl.device\",\"riegl.device_geometry\",\"riegl.geo_tag\",\"r"
    "iegl.georeferencing_parameters\",\"riegl.scan_pattern?\",\"riegl.time_base"
    "\",\"riegl.plane_patch_statistics?\",\"riegl.plane_slope_class_info?\"],\"id"
    "entifier\":\"scan.ptch\",\"attributes\":[\"riegl.xyz*\",\"riegl.xyz_socs\",\"rie"
    "gl.direction?\",\"riegl.direction_medium?\",\"riegl.direction_coarse?\",\"ri"
    "egl.surface_normal\",\"riegl.plane_up\",\"riegl.timestamp\",\"riegl.reflecta"
    "nce?\",\"riegl.point_count\",\"riegl.std_dev\",\"riegl.plane_width\",\"riegl.p"
    "lane_height\",\"riegl.plane_count\",\"riegl.mirror_facet\",\"riegl.covarianc"
    "es\",\"riegl.id\",\"riegl.plane_slope_class?\",\"riegl.plane_occupancy\",\"rie"
    "gl.plane_confidence_normal\",\"riegl.plane_cog_link\",\"riegl.match_count\""
    ",\"riegl.platform_rpy_ROCS_NED\",\"riegl.platform_xyz_ROCS_ENU\",\"riegl.pl"
    "atform_drpy_ROCS_NED\",\"riegl.platform_dxyz_ROCS_ENU\",\"riegl.sda.shift_"
    "vector\",\"riegl.raw_range\",\"riegl.raw_frame_angle\",\"riegl.raw_line_angl"
    "e\"],\"extension\":\"ptch\"}"
);

// Schema for ".ptch" files
const char* const RDB_SCHEMA_RIEGL_SCANPOS_PTCH(
    "{\"metadata\":[\"riegl.device\",\"riegl.geo_tag?\",\"riegl.scan_pattern?\",\"ri"
    "egl.time_base?\",\"riegl.plane_patch_statistics?\"],\"identifier\":\"scanpos"
    ".ptch\",\"attributes\":[\"riegl.xyz*\",\"riegl.surface_normal\",\"riegl.plane_"
    "up\",\"riegl.reflectance?\",\"riegl.point_count\",\"riegl.std_dev\",\"riegl.pl"
    "ane_width\",\"riegl.plane_height\",\"riegl.plane_count\",\"riegl.covariances"
    "\",\"riegl.id\"],\"extension\":\"ptch\"}"
);

// Schema for ".rdbx" files
const char* const RDB_SCHEMA_RIEGL_RDBX(
    "{\"metadata\":[\"riegl.atmosphere\",\"riegl.beam_geometry\",\"riegl.device_ge"
    "ometry\",\"riegl.device\",\"riegl.gaussian_decomposition?\",\"riegl.exponent"
    "ial_decomposition?\",\"riegl.geo_tag\",\"riegl.georeferencing_parameters\","
    "\"riegl.mta_settings?\",\"riegl.near_range_correction?\",\"riegl.noise_esti"
    "mates?\",\"riegl.angular_notch_filter?\",\"riegl.notch_filter?\",\"riegl.poi"
    "ntcloud_info?\",\"riegl.pulse_position_modulation?\",\"riegl.range_statist"
    "ics?\",\"riegl.receiver_internals?\",\"riegl.reflectance_calculation?\",\"ri"
    "egl.reflectance_correction?\",\"riegl.scan_pattern\",\"riegl.time_base\",\"r"
    "iegl.waveform_settings?\",\"riegl.window_analysis?\",\"riegl.window_echo_c"
    "orrection?\"],\"identifier\":\"rdbx\",\"attributes\":[\"riegl.id\",\"riegl.times"
    "tamp\",\"riegl.xyz*\",\"riegl.xyz_socs\",\"riegl.direction_medium?\",\"riegl.d"
    "irection?\",\"riegl.amplitude\",\"riegl.reflectance?\",\"riegl.deviation?\",\""
    "riegl.pulse_width?\",\"riegl.target_index\",\"riegl.target_count\",\"riegl.m"
    "irror_facet?\",\"riegl.scan_segment?\",\"riegl.mta_uncertain_point?\",\"rieg"
    "l.mta_zone?\",\"riegl.window_echo_impact_corrected?\",\"riegl.dyntrig_unce"
    "rtain_point?\",\"riegl.rgba?\",\"riegl.class?\",\"riegl.start_of_scan_line?\""
    ",\"riegl.end_of_scan_line?\",\"riegl.source_indicator?\",\"riegl.fwa?\",\"rie"
    "gl.waveform_available?\",\"riegl.wfm_sbl_id?\",\"riegl.wfm_echo_time_offse"
    "t?\",\"riegl.scan_angle\",\"riegl.scan_direction\",\"riegl.source_index?\",\"r"
    "iegl.scan_line_index?\",\"riegl.shot_index_line?\",\"riegl.hydro_intersect"
    "ion_point?\",\"riegl.hydro_intersection_normal?\",\"riegl.extinction?\",\"ri"
    "egl.svb_amplitude_volumetric?\",\"riegl.svb_surface?\",\"riegl.svb_bottom?"
    "\",\"riegl.svb_path_length?\"],\"extension\":\"rdbx\"}"
);

// Schema for ".rmvx" files
const char* const RDB_SCHEMA_RIEGL_RMVX(
    "{\"metadata\":[\"riegl.geo_tag\",\"riegl.voxel_info\",\"riegl.time_base?\"],\"i"
    "dentifier\":\"rmvx\",\"attributes\":[\"riegl.id\",\"riegl.voxel_index*\",\"riegl"
    ".amplitude\",\"riegl.reflectance\",\"riegl.deviation\",\"riegl.direction_med"
    "ium\",\"riegl.point_count\",\"riegl.voxel_linear_sums\",\"riegl.voxel_square"
    "_sums\",\"riegl.timestamp_min?\",\"riegl.timestamp_max?\"],\"extension\":\"rmv"
    "x\"}"
);

// Schema for ".s10x" files
const char* const RDB_SCHEMA_RIEGL_S10X(
    "{\"metadata\":[\"riegl.time_base\",\"riegl.device?\",\"riegl.pose_sensors\"],\""
    "identifier\":\"s10x\",\"attributes\":[\"riegl.id\",\"riegl.timestamp*\",\"riegl."
    "frame_angle_coarse\",\"riegl.gyroscope_raw\",\"riegl.accelerometer_raw\",\"r"
    "iegl.magnetic_field_sensor_raw\",\"riegl.gyroscope\",\"riegl.accelerometer"
    "\",\"riegl.magnetic_field_sensor\",\"riegl.barometric_height_amsl\",\"riegl."
    "temperature\",\"riegl.line_scan_active\",\"riegl.frame_scan_active\",\"riegl"
    ".data_acquisition_active\"],\"extension\":\"s10x\"}"
);

// Schema for ".sbx" files
const char* const RDB_SCHEMA_RIEGL_SBX(
    "{\"metadata\":[],\"identifier\":\"sbx\",\"attributes\":[\"riegl.id*\",\"riegl.wfm"
    "_sbl_channel\",\"riegl.wfm_sbl_mean\",\"riegl.wfm_sbl_std_dev\",\"riegl.wfm_"
    "sbl_time_offset\",\"riegl.wfm_sda_first\",\"riegl.wfm_sda_count\"],\"extensi"
    "on\":\"sbx\"}"
);

// Schema for ".sdcx" files
const char* const RDB_SCHEMA_RIEGL_SDCX(
    "{\"metadata\":[\"riegl.atmosphere\",\"riegl.beam_geometry\",\"riegl.device_ge"
    "ometry\",\"riegl.device\",\"riegl.gaussian_decomposition?\",\"riegl.exponent"
    "ial_decomposition?\",\"riegl.mta_settings?\",\"riegl.near_range_correction"
    "?\",\"riegl.noise_estimates?\",\"riegl.angular_notch_filter?\",\"riegl.notch"
    "_filter?\",\"riegl.pointcloud_info?\",\"riegl.pulse_position_modulation?\","
    "\"riegl.range_statistics?\",\"riegl.receiver_internals?\",\"riegl.reflectan"
    "ce_calculation?\",\"riegl.reflectance_correction?\",\"riegl.scan_pattern\","
    "\"riegl.time_base\",\"riegl.window_analysis?\",\"riegl.window_echo_correcti"
    "on?\"],\"identifier\":\"sdcx\",\"attributes\":[\"riegl.id\",\"riegl.timestamp*\","
    "\"riegl.xyz\",\"riegl.amplitude\",\"riegl.reflectance?\",\"riegl.deviation?\","
    "\"riegl.pulse_width?\",\"riegl.target_index\",\"riegl.target_count\",\"riegl."
    "mirror_facet?\",\"riegl.scan_segment?\",\"riegl.mta_uncertain_point?\",\"rie"
    "gl.mta_zone?\",\"riegl.window_echo_impact_corrected?\",\"riegl.dyntrig_unc"
    "ertain_point?\",\"riegl.class?\",\"riegl.start_of_scan_line?\",\"riegl.end_o"
    "f_scan_line?\",\"riegl.source_indicator?\",\"riegl.fwa?\",\"riegl.waveform_a"
    "vailable?\",\"riegl.wfm_sbl_id?\",\"riegl.wfm_echo_time_offset?\",\"riegl.ex"
    "tinction?\",\"riegl.svb_amplitude_volumetric?\",\"riegl.svb_surface?\",\"rie"
    "gl.svb_bottom?\",\"riegl.svb_path_length?\"],\"extension\":\"sdcx\"}"
);

// Schema for ".sidx" files
const char* const RDB_SCHEMA_RIEGL_SIDX(
    "{\"metadata\":[\"riegl.shot_info\",\"riegl.echo_info\"],\"identifier\":\"sidx\","
    "\"attributes\":[\"riegl.id\",\"riegl.shot_timestamp_hr*\",\"riegl.echo_first\""
    ",\"riegl.echo_count\"],\"extension\":\"sidx\"}"
);

// Schema for ".sodx" files
const char* const RDB_SCHEMA_RIEGL_SODX(
    "{\"metadata\":[\"riegl.atmosphere\",\"riegl.device\",\"riegl.device_geometry\""
    ",\"riegl.device_output_limits\",\"riegl.beam_geometry\",\"riegl.near_range_"
    "correction?\",\"riegl.window_echo_correction?\",\"riegl.receiver_internals"
    "?\",\"riegl.gaussian_decomposition?\",\"riegl.exponential_decomposition?\","
    "\"riegl.mta_settings?\",\"riegl.pulse_position_modulation?\",\"riegl.notch_"
    "filter?\",\"riegl.reflectance_calculation?\",\"riegl.scan_pattern\",\"riegl."
    "time_base\",\"riegl.waveform_info?\",\"riegl.echo_info?\"],\"identifier\":\"so"
    "dx\",\"attributes\":[\"riegl.id\",\"riegl.shot_timestamp_hr*\",\"riegl.mirror_"
    "facet\",\"riegl.scan_segment\",\"riegl.start_of_scan_line\",\"riegl.line_ang"
    "le_coarse\",\"riegl.shot_origin\",\"riegl.shot_biaxial_shift?\",\"riegl.shot"
    "_direction\",\"riegl.shot_direction_levelled?\",\"riegl.wfm_sbl_first?\",\"r"
    "iegl.wfm_sbl_count?\",\"riegl.echo_first?\",\"riegl.echo_count?\"],\"extensi"
    "on\":\"sodx\"}"
);

// Schema for ".sp{C}" files
const char* const RDB_SCHEMA_RIEGL_SPC(
    "{\"metadata\":[],\"identifier\":\"sp{C}\",\"attributes\":[\"riegl.id*\",\"riegl.w"
    "fm_sample_value\"],\"extension\":\"sp{C}\"}"
);

// Schema for ".vtx" files
const char* const RDB_SCHEMA_RIEGL_VTX(
    "{\"metadata\":[\"riegl.geo_tag\"],\"identifier\":\"vtx\",\"attributes\":[\"riegl."
    "id*\",\"riegl.xyz\",\"riegl.xyz_accuracies?\"],\"extension\":\"vtx\"}"
);

// Schema for ".vxls" files
const char* const RDB_SCHEMA_RIEGL_VXLS(
    "{\"metadata\":[\"riegl.voxel_info\",\"riegl.geo_tag?\"],\"identifier\":\"vxls\","
    "\"attributes\":[\"riegl.id\",\"riegl.xyz*\",\"riegl.covariances\",\"riegl.pca_a"
    "xis_max\",\"riegl.pca_axis_min\",\"riegl.pca_extents\",\"riegl.point_count\","
    "\"riegl.reflectance\",\"riegl.shape_id\",\"riegl.voxel_collapsed\",\"riegl.st"
    "d_dev?\"],\"extension\":\"vxls\"}"
);

// Schema for ".wdcx" files
const char* const RDB_SCHEMA_RIEGL_WDCX(
    "{\"metadata\":[\"riegl.atmosphere\",\"riegl.beam_geometry\",\"riegl.device_ge"
    "ometry\",\"riegl.device\",\"riegl.gaussian_decomposition?\",\"riegl.exponent"
    "ial_decomposition?\",\"riegl.geo_tag\",\"riegl.georeferencing_parameters\","
    "\"riegl.mta_settings?\",\"riegl.near_range_correction?\",\"riegl.noise_esti"
    "mates?\",\"riegl.angular_notch_filter?\",\"riegl.notch_filter?\",\"riegl.poi"
    "ntcloud_info?\",\"riegl.pulse_position_modulation?\",\"riegl.range_statist"
    "ics?\",\"riegl.receiver_internals?\",\"riegl.reflectance_calculation?\",\"ri"
    "egl.reflectance_correction?\",\"riegl.scan_pattern\",\"riegl.time_base\",\"r"
    "iegl.waveform_settings?\",\"riegl.window_analysis?\",\"riegl.window_echo_c"
    "orrection?\"],\"identifier\":\"wdcx\",\"attributes\":[\"riegl.id\",\"riegl.times"
    "tamp\",\"riegl.xyz*\",\"riegl.xyz_socs\",\"riegl.direction_medium?\",\"riegl.d"
    "irection?\",\"riegl.amplitude\",\"riegl.reflectance?\",\"riegl.deviation?\",\""
    "riegl.pulse_width?\",\"riegl.target_index\",\"riegl.target_count\",\"riegl.m"
    "irror_facet?\",\"riegl.scan_segment?\",\"riegl.mta_uncertain_point?\",\"rieg"
    "l.mta_zone?\",\"riegl.window_echo_impact_corrected?\",\"riegl.dyntrig_unce"
    "rtain_point?\",\"riegl.rgba?\",\"riegl.class?\",\"riegl.start_of_scan_line?\""
    ",\"riegl.end_of_scan_line?\",\"riegl.source_indicator?\",\"riegl.fwa?\",\"rie"
    "gl.waveform_available?\",\"riegl.wfm_sbl_id?\",\"riegl.wfm_echo_time_offse"
    "t?\",\"riegl.scan_angle\",\"riegl.scan_direction\",\"riegl.source_index?\",\"r"
    "iegl.scan_line_index?\",\"riegl.shot_index_line?\",\"riegl.hydro_intersect"
    "ion_point?\",\"riegl.hydro_intersection_normal?\",\"riegl.extinction?\",\"ri"
    "egl.svb_amplitude_volumetric?\",\"riegl.svb_surface?\",\"riegl.svb_bottom?"
    "\",\"riegl.svb_path_length?\"],\"extension\":\"wdcx\"}"
);

// Schema for ".wex" files
const char* const RDB_SCHEMA_RIEGL_WEX(
    "{\"metadata\":[\"riegl.device\",\"riegl.notch_filter\",\"riegl.window_analysi"
    "s\"],\"identifier\":\"wex\",\"attributes\":[\"riegl.id\",\"riegl.timestamp*\",\"ri"
    "egl.wex_filter_valid\",\"riegl.wex_point_count\",\"riegl.wex_amplitude\",\"r"
    "iegl.wex_amplitude_std_dev\",\"riegl.wex_amplitude_min\",\"riegl.wex_ampli"
    "tude_max\",\"riegl.wex_amplitude_offset\",\"riegl.wex_deviation\",\"riegl.we"
    "x_deviation_std_dev\",\"riegl.wex_deviation_min\",\"riegl.wex_deviation_ma"
    "x\",\"riegl.wex_range\",\"riegl.wex_range_std_dev\",\"riegl.wex_range_min\",\""
    "riegl.wex_range_max\",\"riegl.wex_filter_range_min\",\"riegl.wex_filter_ra"
    "nge_max\",\"riegl.wex_filter_amplitude_max\"],\"extension\":\"wex\"}"
);

// Table of all RDB file schema strings
const char* const RDB_SCHEMA_ARRAY[] = {
    RDB_SCHEMA_RIEGL_AVG_FWA,
    RDB_SCHEMA_RIEGL_AVG_SBX,
    RDB_SCHEMA_RIEGL_AVG_SIDX,
    RDB_SCHEMA_RIEGL_AVG_SPC,
    RDB_SCHEMA_RIEGL_CPX,
    RDB_SCHEMA_RIEGL_DOIX,
    RDB_SCHEMA_RIEGL_EIFX,
    RDB_SCHEMA_RIEGL_EPFX,
    RDB_SCHEMA_RIEGL_FWA,
    RDB_SCHEMA_RIEGL_LLHX,
    RDB_SCHEMA_RIEGL_MPX,
    RDB_SCHEMA_RIEGL_MTCH,
    RDB_SCHEMA_RIEGL_MVX,
    RDB_SCHEMA_RIEGL_OBSX,
    RDB_SCHEMA_RIEGL_OPEFX,
    RDB_SCHEMA_RIEGL_OPP,
    RDB_SCHEMA_RIEGL_OPX,
    RDB_SCHEMA_RIEGL_OWP,
    RDB_SCHEMA_RIEGL_PEFX,
    RDB_SCHEMA_RIEGL_PROJECT_POFX,
    RDB_SCHEMA_RIEGL_SCAN_POFX,
    RDB_SCHEMA_RIEGL_PROJECT_POQX,
    RDB_SCHEMA_RIEGL_SCAN_POQX,
    RDB_SCHEMA_RIEGL_PPX,
    RDB_SCHEMA_RIEGL_PROJECT_PTCH,
    RDB_SCHEMA_RIEGL_SCAN_PTCH,
    RDB_SCHEMA_RIEGL_SCANPOS_PTCH,
    RDB_SCHEMA_RIEGL_RDBX,
    RDB_SCHEMA_RIEGL_RMVX,
    RDB_SCHEMA_RIEGL_S10X,
    RDB_SCHEMA_RIEGL_SBX,
    RDB_SCHEMA_RIEGL_SDCX,
    RDB_SCHEMA_RIEGL_SIDX,
    RDB_SCHEMA_RIEGL_SODX,
    RDB_SCHEMA_RIEGL_SPC,
    RDB_SCHEMA_RIEGL_VTX,
    RDB_SCHEMA_RIEGL_VXLS,
    RDB_SCHEMA_RIEGL_WDCX,
    RDB_SCHEMA_RIEGL_WEX
};
const size_t RDB_SCHEMA_COUNT(
    sizeof(RDB_SCHEMA_ARRAY) / sizeof(RDB_SCHEMA_ARRAY[0])
);

#endif // RDB_2125FB67_4790_4EE4_BC63_844F2ACC9D90
